@@ -3,7 +3,7 @@ package Data::Seek::Data;
 
 use parent 'Data::Object::Hash';
 
-our $VERSION = '0.07'; # VERSION
+our $VERSION = '0.08'; # VERSION
 
 sub decode {
     return shift->unfold;
@@ -27,7 +27,7 @@ Data::Seek::Data - Data::Seek Data Structure Container
 
 =head1 VERSION
 
-version 0.07
+version 0.08
 
 =head1 SYNOPSIS
 
@@ -38,31 +38,19 @@ version 0.07
 Data::Seek::Data is a class within L<Data::Seek> which acts as a container for a
 data structure which is intended to be provided to L<Data::Seek::Search>.
 
-=head1 ATTRIBUTES
-
-=head2 object
-
-    $data->object;
-    $data->object($hash);
-
-Contains the data structure to be introspected, encoded and/or decoded, and must
-be a hash reference.
-
 =head1 METHODS
 
 =head2 decode
 
     my $hash = $data->decode;
 
-Uses L<Hash::Flatten> to unflatten/unfold the data structure returning a hash
-reference.
+The decode method unflatten/unfolds the data structure returning a hash object.
 
 =head2 encode
 
     my $hash = $data->encode;
 
-Uses L<Hash::Flatten> to flatten/fold the data structure returning a hash
-reference.
+The encode method flatten/fold the data structure returning a hash object.
 
 =head1 AUTHOR
 
